@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -82,6 +83,7 @@ public abstract class AltosUIUnitsIndicator extends AltosUIIndicator {
 	public void show (AltosState state, AltosListenerState listener_state) {
 		double[] v = new double[values.length];
 
+		hide = false;
 		for (int i = 0; i < values.length; i++) {
 			if (state != null)
 				v[i] = value(state, listener_state, i);
