@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +33,7 @@ main(void)
 
 	ao_task_init();
 	ao_led_init(LEDS_AVAILABLE);
-	ao_led_on(AO_LED_RED);
+	ao_led_on(LEDS_AVAILABLE);
 	ao_timer_init();
 
 	ao_spi_init();
@@ -52,7 +53,7 @@ main(void)
 
 	ao_config_init();
 
-	ao_led_off(AO_LED_RED);
+	ao_led_off(LEDS_AVAILABLE);
 
 	ao_start_scheduler();
 	return 0;
