@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,24 +18,31 @@
 
 #include <ao.h>
 #include <ao_exti.h>
-#include <ao_tracker.h>
+#include <ao_fat.h>
+#include <ao_eeprom.h>
+
+uint16_t	ao_flight_number = 1;
 
 int
 main(void)
 {
 	ao_clock_init();
-
+	
 #if HAS_STACK_GUARD
 	ao_mpu_init();
 #endif
 
 	ao_task_init();
+//	ao_led_init(LEDS_AVAILABLE);
+//	ao_led_on(AO_LED_RED);
 	ao_timer_init();
 
+
 	ao_spi_init();
+	ao_dma_init();
 	ao_exti_init();
 
-	ao_storage_init();
+	ao_eeprom_init();
 
 	ao_serial_init();
 
@@ -43,24 +51,20 @@ main(void)
 	ao_usb_init();
 	ao_radio_init();
 
-#if HAS_ADC
-	ao_adc_init();
-#endif
+	ao_fat_init();
 
 	ao_gps_init();
-#if HAS_LOG
-	ao_log_init();
-#endif
-
-	ao_tracker_init();
+	ao_gps_report_mega_init();
 
 	ao_telemetry_init();
+	ao_telemetry_set_interval(AO_SEC_TO_TICKS(1));
+	ao_rdf_set(1);
 
 #if HAS_SAMPLE_PROFILE
 	ao_sample_profile_init();
 #endif
 	ao_config_init();
-
+	
 	ao_start_scheduler();
 	return 0;
 }
