@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -43,7 +44,7 @@
 #define AO_APB2_PRESCALER	2
 #define AO_RCC_CFGR_PPRE2_DIV	STM_RCC_CFGR_PPRE2_DIV_2
 
-#define HAS_SERIAL_1		1
+#define HAS_SERIAL_1		0
 #define USE_SERIAL_1_STDIN	0
 #define SERIAL_1_PB6_PB7	0
 #define SERIAL_1_PA9_PA10	1
@@ -84,7 +85,7 @@
 #define HAS_SPI_1		1
 #define SPI_1_PA5_PA6_PA7	1	/* Barometer */
 #define SPI_1_PB3_PB4_PB5	0
-#define SPI_1_PE13_PE14_PE15	1	/* Accelerometer */
+#define SPI_1_PE13_PE14_PE15	1	/* Accelerometer, Gyro */
 #define SPI_1_OSPEEDR		STM_OSPEEDR_10MHz
 
 #define HAS_SPI_2		1
@@ -100,8 +101,8 @@
 #define HAS_I2C_1		1
 #define I2C_1_PB8_PB9		1
 
-#define HAS_I2C_2		1
-#define I2C_2_PB10_PB11		1
+#define HAS_I2C_2		0
+#define I2C_2_PB10_PB11		0
 
 #define PACKET_HAS_SLAVE	1
 #define PACKET_HAS_MASTER	0
@@ -301,24 +302,24 @@ struct ao_adc {
 
 /* gets pretty close to 434.550 */
 
-#define AO_RADIO_CAL_DEFAULT 	0x6ca333
+#define AO_RADIO_CAL_DEFAULT 	5695733
 
 #define AO_FEC_DEBUG		0
-#define AO_CC1120_SPI_CS_PORT	(&stm_gpioc)
-#define AO_CC1120_SPI_CS_PIN	5
-#define AO_CC1120_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
-#define AO_CC1120_SPI		stm_spi2
+#define AO_CC1200_SPI_CS_PORT	(&stm_gpioc)
+#define AO_CC1200_SPI_CS_PIN	5
+#define AO_CC1200_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
+#define AO_CC1200_SPI		stm_spi2
 
-#define AO_CC1120_INT_PORT		(&stm_gpioc)
-#define AO_CC1120_INT_PIN		14
-#define AO_CC1120_MCU_WAKEUP_PORT	(&stm_gpioc)
-#define AO_CC1120_MCU_WAKEUP_PIN	(0)
+#define AO_CC1200_INT_PORT		(&stm_gpioe)
+#define AO_CC1200_INT_PIN		1
+#define AO_CC1200_MCU_WAKEUP_PORT	(&stm_gpioc)
+#define AO_CC1200_MCU_WAKEUP_PIN	(0)
 
-#define AO_CC1120_INT_GPIO	2
-#define AO_CC1120_INT_GPIO_IOCFG	CC1120_IOCFG2
+#define AO_CC1200_INT_GPIO	2
+#define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
 
-#define AO_CC1120_MARC_GPIO	3
-#define AO_CC1120_MARC_GPIO_IOCFG	CC1120_IOCFG3
+#define AO_CC1200_MARC_GPIO	3
+#define AO_CC1200_MARC_GPIO_IOCFG	CC1200_IOCFG3
 
 #define HAS_BOOT_RADIO		0
 
@@ -326,7 +327,7 @@ struct ao_adc {
  * Mag sensor (hmc5883)
  */
 
-#define HAS_HMC5883		0
+#define HAS_HMC5883		1
 #define AO_HMC5883_INT_PORT	(&stm_gpioc)
 #define AO_HMC5883_INT_PIN	12
 #define AO_HMC5883_I2C_INDEX	STM_I2C_INDEX(1)
@@ -335,10 +336,12 @@ struct ao_adc {
  * mpu6000
  */
 
-#define HAS_MPU6000		1	
-#define AO_MPU6000_INT_PORT	(&stm_gpioc)
-#define AO_MPU6000_INT_PIN	13
-#define AO_MPU6000_I2C_INDEX	STM_I2C_INDEX(1)
+#define HAS_MPU6000		1
+#define AO_MPU6000_INT_PORT	(&stm_gpioe)
+#define AO_MPU6000_INT_PIN	0
+#define AO_MPU6000_SPI_BUS	AO_SPI_1_PE13_PE14_PE15
+#define AO_MPU6000_SPI_CS_PORT	(&stm_gpiod)
+#define AO_MPU6000_SPI_CS_PIN	2
 #define HAS_IMU			1
 
 /*
@@ -357,8 +360,10 @@ struct ao_adc {
  * Companion
  */
 
-#define AO_COMPANION_CS_PORT	(&stm_gpiod)
-#define AO_COMPANION_CS_PIN	(0)
+#define AO_COMPANION_CS_PORT	(&stm_gpiob)
+#define AO_COMPANION_CS_PIN_0	(6)
+#define AO_COMPANION_CS_PIN	AO_COMPANION_CS_PIN_0
+#define AO_COMPANION_CS_PIN_1	(7)
 #define AO_COMPANION_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
 
 /*
@@ -379,4 +384,26 @@ struct ao_adc {
 #define AO_PROFILE	       	0
 #endif
 
+/*
+ * PWM output
+ */
+
+#define NUM_PWM			4
+#define PWM_MAX			20000
+#define AO_PWM_TIMER		stm_tim4
+#define AO_PWM_TIMER_ENABLE	STM_RCC_APB1ENR_TIM4EN
+#define AO_PWM_TIMER_SCALE	32
+
+#define AO_PWM_0_GPIO		(&stm_gpiod)
+#define AO_PWM_0_PIN		12
+
+#define AO_PWM_1_GPIO		(&stm_gpiod)
+#define AO_PWM_1_PIN		13
+
+#define AO_PWM_2_GPIO		(&stm_gpiod)
+#define AO_PWM_2_PIN		14
+
+#define AO_PWM_3_GPIO		(&stm_gpiod)
+#define AO_PWM_3_PIN		15
+
 #endif /* _AO_PINS_H_ */
