@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -247,29 +248,28 @@ struct ao_adc {
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * Radio (cc1120)
+ * Radio (cc1200)
  */
 
 /* gets pretty close to 434.550 */
 
-#define AO_RADIO_CAL_DEFAULT 	0x6ca333
+#define AO_RADIO_CAL_DEFAULT 	5695733
 
-#define AO_FEC_DEBUG		0
-#define AO_CC1120_SPI_CS_PORT	(&stm_gpioa)
-#define AO_CC1120_SPI_CS_PIN	2
-#define AO_CC1120_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
-#define AO_CC1120_SPI		stm_spi2
+#define AO_CC1200_SPI_CS_PORT	(&stm_gpioa)
+#define AO_CC1200_SPI_CS_PIN	2
+#define AO_CC1200_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
+#define AO_CC1200_SPI		stm_spi2
 
-#define AO_CC1120_INT_PORT		(&stm_gpioa)
-#define AO_CC1120_INT_PIN		(3)
-#define AO_CC1120_MCU_WAKEUP_PORT	(&stm_gpioa)
-#define AO_CC1120_MCU_WAKEUP_PIN	(4)
+#define AO_CC1200_INT_PORT		(&stm_gpioa)
+#define AO_CC1200_INT_PIN		(3)
+#define AO_CC1200_MCU_WAKEUP_PORT	(&stm_gpioa)
+#define AO_CC1200_MCU_WAKEUP_PIN	(4)
 
-#define AO_CC1120_INT_GPIO	2
-#define AO_CC1120_INT_GPIO_IOCFG	CC1120_IOCFG2
+#define AO_CC1200_INT_GPIO	2
+#define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
 
-#define AO_CC1120_MARC_GPIO	3
-#define AO_CC1120_MARC_GPIO_IOCFG	CC1120_IOCFG3
+#define AO_CC1200_MARC_GPIO	3
+#define AO_CC1200_MARC_GPIO_IOCFG	CC1200_IOCFG3
 
 #define HAS_BOOT_RADIO		0
 
